==> boost_1_80_0.tar.bz2: boost_1_80_0/libs/locale/doc/html/appendix.js <==
var appendix =
[
    [ "Table of Contents", "appendix.html#appendix_toc", null ],
    [ "Design Rationale", "rationale.html", [
      [ "Why is it needed?", "rationale.html#rationale_why", null ],
      [ "Why use an ICU wrapper instead of ICU?", "rationale.html#why_icu", null ],
      [ "Why an ICU wrapper and not an implementation-from-scratch?", "rationale.html#why_icu_wrapper", null ],
      [ "Why is the ICU API not exposed to the user?", "rationale.html#why_icu_api_is_hidden", null ],
      [ "Why use GNU Gettext catalogs for message formatting?", "rationale.html#why_gnu_gettext", null ],
      [ "Why is a plain number used for the representation of a date-time, instead of a Boost.DateTime date or Boost.DateTime ptime?", "rationale.html#why_plain_number", null ],
      [ "Why are POSIX locale names used and not something like the BCP-47 IETF language tag?", "rationale.html#why_posix_names", null ],
      [ "Why most parts of Boost.Locale work only on linear/contiguous chunks of text", "rationale.html#why_linear_chunks", null ],
      [ "Why all Boost.Locale implementation is hidden behind abstract interfaces and does not use template metaprogramming?", "rationale.html#why_abstract_api", null ],
      [ "Why Boost.Locale does not provide char16_t/char32_t for non-C++0x platforms.", "rationale.html#why_no_special_character_type", null ]
    ] ],
    [ "Frequently Asked Questions", "faq.html", null ],
    [ "Default Encoding under Microsoft Windows", "default_encoding_under_windows.html", null ],
    [ "Running Examples under Microsoft Windows", "running_examples_under_windows.html", null ],
    [ "Using Gettext Tools on Windows", "gettext_for_windows.html", [
      [ "Getting gettext utilities from CppCMS project", "gettext_for_windows.html#gettext_for_windows_cppcms", null ],
      [ "Getting Gettext via MinGW project", "gettext_for_windows.html#gettext_for_windows_mingw", null ],
      [ "Building latest version on your own.", "gettext_for_windows.html#gettext_for_windows_build", null ],
      [ "Using Cygwin", "gettext_for_windows.html#gettext_for_windows_cygwin", null ]
    ] ],
    [ "Glossary", "glossary.html", null ],
    [ "Tested Compilers and Platforms", "tested_compilers_and_platforms.html", [
      [ "Known Issues", "tested_compilers_and_platforms.html#tested_compilers_and_platforms_issues", null ]
    ] ],
    [ "Status of C++11 char16_t/char32_t support", "status_of_cpp0x_characters_support.html", [
      [ "GNU GCC 4.5/C++11 Status", "status_of_cpp0x_characters_support.html#status_of_cpp0x_characters_support_gnu", null ],
      [ "Visual Studio 2010 (MSVC10)/C++11 Status", "status_of_cpp0x_characters_support.html#status_of_cpp0x_characters_support_msvc", null ]
    ] ],
    [ "Special Thanks", "special_thanks.html", null ]
];

==> boost_1_84_0.tar.bz2: boost_1_84_0/libs/locale/doc/html/appendix.js <==
var appendix =
[
    [ "Table of Contents", "appendix.html#appendix_toc", null ],
    [ "Design Rationale", "rationale.html", [
      [ "Why do I need Boost.Locale?", "rationale.html#rationale_why", null ],
      [ "Why use an ICU wrapper instead of ICU?", "rationale.html#why_icu", null ],
      [ "Why an ICU wrapper and not an implementation-from-scratch?", "rationale.html#why_icu_wrapper", null ],
      [ "Why is the ICU API not exposed to the user?", "rationale.html#why_icu_api_is_hidden", null ],
      [ "Why use GNU Gettext catalogs for message formatting?", "rationale.html#why_gnu_gettext", null ],
      [ "Why is a plain number used for the representation of a date-time, instead of a Boost.DateTime date or Boost.DateTime ptime?", "rationale.html#why_plain_number", null ],
      [ "Why are POSIX locale names used and not something like the BCP-47 IETF language tag?", "rationale.html#why_posix_names", null ],
      [ "Why do most parts of Boost.Locale work only on linear/contiguous chunks of text?", "rationale.html#why_linear_chunks", null ],
      [ "Why is all Boost.Locale implementation hidden behind abstract interfaces instead of using template metaprogramming?", "rationale.html#why_abstract_api", null ],
      [ "Why doesn't Boost.Locale provide char16_t/char32_t for non-C++11 platforms?", "rationale.html#why_no_special_character_type", null ]
    ] ],
    [ "Frequently Asked Questions", "faq.html", null ],
    [ "Default Encoding under Microsoft Windows", "default_encoding_under_windows.html", null ],
    [ "Running Examples under Microsoft Windows", "running_examples_under_windows.html", null ],
    [ "Using Gettext Tools on Windows", "gettext_for_windows.html", [
      [ "Getting Gettext Utilities from CppCMS", "gettext_for_windows.html#gettext_for_windows_cppcms", null ],
      [ "Getting Gettext via MinGW", "gettext_for_windows.html#gettext_for_windows_mingw", null ],
      [ "Building the latest version on your own.", "gettext_for_windows.html#gettext_for_windows_build", null ],
      [ "Using Cygwin", "gettext_for_windows.html#gettext_for_windows_cygwin", null ]
    ] ],
    [ "Glossary", "glossary.html", null ],
    [ "Tested Compilers and Platforms", "tested_compilers_and_platforms.html", [
      [ "Known Issues", "tested_compilers_and_platforms.html#tested_compilers_and_platforms_issues", null ]
    ] ],
    [ "Status of C++11 char16_t/char32_t support", "status_of_cpp0x_characters_support.html", [
      [ "GNU GCC 4.5/C++11 Status", "status_of_cpp0x_characters_support.html#status_of_cpp0x_characters_support_gnu", null ],
      [ "Visual Studio 2010 (MSVC10)/C++11 Status", "status_of_cpp0x_characters_support.html#status_of_cpp0x_characters_support_msvc", null ]
    ] ],
    [ "Special Thanks", "special_thanks.html", null ]
];
